@@ -1,7 +1,7 @@
 /*
  * EPUB exporting functions for HTMLDOC, a HTML document processing program.
  *
- * Copyright 2017-2019 by Michael R Sweet.
+ * Copyright © 2017-2021 by Michael R Sweet.
  *
  * This program is free software.  Distribution and use rights are outlined in
  * the file "COPYING".
@@ -572,7 +572,8 @@ write_title(zipc_file_t *out,           /* I - Output file */
     {
       image_t *img = image_load(TitleImage, !OutputColor);
 
-      status |= write_xhtmlf(out, "      <p><img src=\"%s\" width=\"%d\" height=\"%d\" alt=\"%s\" /></p>\n", file_basename((char *)TitleImage), img->width, img->height, title ? title : (uchar *)"");
+      if (img)
+        status |= write_xhtmlf(out, "      <p><img src=\"%s\" width=\"%d\" height=\"%d\" alt=\"%s\" /></p>\n", file_basename((char *)TitleImage), img->width, img->height, title ? title : (uchar *)"");
     }
 
     if (title != NULL)
@@ -1465,5 +1466,7 @@ write_xhtmlf(zipc_file_t *out,          /* I - Output file */
   if (ptr > start)
     status |= zipcFileWrite(out, start, (size_t)(ptr - start));
 
+  va_end(ap);
+
   return (status);
 }
